==> kazehakase_0.5.4.orig.tar.gz: kazehakase-0.5.4/src/kz-icons.h <==
/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-icons.h 3266 2007-10-04 04:54:57Z ikezoe $
 */

#ifndef KZ_ICONS_H
#define KZ_ICONS_H

#include <glib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtkenums.h>

G_BEGIN_DECLS

#define KZ_STOCK_ANCHOR             "kz-anchor"
#define KZ_STOCK_BOOKMARK           "kz-bookmark"
#define KZ_STOCK_BOOK_SEARCH        "kz-book-search"
#define KZ_STOCK_CLOSE_BACKWARD     "kz-closebackward"
#define KZ_STOCK_CLOSE_FORWARD      "kz-closeforward"
#define KZ_STOCK_CLOSE_WINDOW       "kz-closewindow"
#define KZ_STOCK_COPY_IMAGE_URL     "kz-copyimagelocation"
#define KZ_STOCK_COPY_URL           "kz-copyurl"
#define KZ_STOCK_EDITOR             "kz-editor"
#define KZ_STOCK_FOLDER             "kz-folder"
#define KZ_STOCK_FOLDER_OPEN        "kz-folder-open"
#define KZ_STOCK_FOLDER_SEARCH      "kz-folder-search"
#define KZ_STOCK_FONT_DECREASE      "kz-font-decrease"
#define KZ_STOCK_FONT_INCREASE      "kz-font-increase"
#define KZ_STOCK_GOOGLE             "kz-google"
#define KZ_STOCK_GREEN              "kz-green"
#define KZ_STOCK_GRAY               "kz-gray"
#define KZ_STOCK_HISTORY            "kz-history"
#define KZ_STOCK_NEW_WINDOW         "kz-newwindow"
#define KZ_STOCK_OPEN_LINK_WINDOW   "kz-openlinkwindow"
#define KZ_STOCK_OPEN_IMAGE_WINDOW  "kz-openimagewindow"
#define KZ_STOCK_OPEN_SELECTED_LINK "kz-openselectedlink"
#define KZ_STOCK_RED                "kz-red"
#define KZ_STOCK_REMOTE_BOOKMARK    "kz-remote-bookmark"
#define KZ_STOCK_RSS_FEED           "kz-rss-feed"
#define KZ_STOCK_SAVE_LINK          "kz-savelink"
#define KZ_STOCK_SCRAP_BOOKMARK     "kz-scrap-bookmark"
#define KZ_STOCK_SEARCH             "kz-search"
#define KZ_STOCK_SEPARATOR          "kz-separator"
#define KZ_STOCK_SMART_BOOKMARK     "kz-smart-bookmark"
#define KZ_STOCK_TAB_NEXT           "kz-tab-next"
#define KZ_STOCK_TAB_PREV           "kz-tab-prev"
#define KZ_STOCK_VIEW_SOURCE        "kz-view-source"
#define KZ_STOCK_YELLOW             "kz-yellow"

#define KZ_STOCK_MOZILLA	    "kz-mozilla"
#define KZ_STOCK_FIREFOX	    "kz-firefox"
#define KZ_STOCK_EPIPHANY	    "kz-epiphany"
#define KZ_STOCK_GALEON		    "kz-galeon"
#define KZ_STOCK_NETSCAPE	    "kz-netscape"
#define KZ_STOCK_KONQUEROR 	    "kz-konqueror"

extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;

extern GdkPixbuf *kz_icon;

void kz_icons_init (void);

G_END_DECLS

#endif /* KZ_ICONS_H */

==> kazehakase_0.5.8.orig.tar.gz: kazehakase-0.5.8/src/kz-icons.h <==
/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-icons.h 3596 2009-01-29 23:07:01Z ikezoe $
 */

#ifndef KZ_ICONS_H
#define KZ_ICONS_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define KZ_STOCK_ANCHOR             "kz-anchor"
#define KZ_STOCK_BOOKMARK           "kz-bookmark"
#define KZ_STOCK_BOOK_SEARCH        "kz-book-search"
#define KZ_STOCK_CLOSE_BACKWARD     "kz-closebackward"
#define KZ_STOCK_CLOSE_FORWARD      "kz-closeforward"
#define KZ_STOCK_CLOSE_WINDOW       "kz-closewindow"
#define KZ_STOCK_COPY_IMAGE_URL     "kz-copyimagelocation"
#define KZ_STOCK_COPY_URL           "kz-copyurl"
#define KZ_STOCK_EDITOR             "kz-editor"
#define KZ_STOCK_FOLDER             "kz-folder"
#define KZ_STOCK_FOLDER_OPEN        "kz-folder-open"
#define KZ_STOCK_FOLDER_SEARCH      "kz-folder-search"
#define KZ_STOCK_FONT_DECREASE      "kz-font-decrease"
#define KZ_STOCK_FONT_INCREASE      "kz-font-increase"
#define KZ_STOCK_GOOGLE             "kz-google"
#define KZ_STOCK_GREEN              "kz-green"
#define KZ_STOCK_GRAY               "kz-gray"
#define KZ_STOCK_HISTORY            "kz-history"
#define KZ_STOCK_NEW_WINDOW         "kz-newwindow"
#define KZ_STOCK_OPEN_LINK_WINDOW   "kz-openlinkwindow"
#define KZ_STOCK_OPEN_IMAGE_WINDOW  "kz-openimagewindow"
#define KZ_STOCK_OPEN_SELECTED_LINK "kz-openselectedlink"
#define KZ_STOCK_RED                "kz-red"
#define KZ_STOCK_REMOTE_BOOKMARK    "kz-remote-bookmark"
#define KZ_STOCK_RSS_FEED           "kz-rss-feed"
#define KZ_STOCK_SAVE_LINK          "kz-savelink"
#define KZ_STOCK_SCRAP_BOOKMARK     "kz-scrap-bookmark"
#define KZ_STOCK_SEARCH             "kz-search"
#define KZ_STOCK_SEPARATOR          "kz-separator"
#define KZ_STOCK_SMART_BOOKMARK     "kz-smart-bookmark"
#define KZ_STOCK_TAB_NEXT           "kz-tab-next"
#define KZ_STOCK_TAB_PREV           "kz-tab-prev"
#define KZ_STOCK_VIEW_SOURCE        "kz-view-source"
#define KZ_STOCK_YELLOW             "kz-yellow"

#define KZ_STOCK_MOZILLA	    "kz-mozilla"
#define KZ_STOCK_FIREFOX	    "kz-firefox"
#define KZ_STOCK_EPIPHANY	    "kz-epiphany"
#define KZ_STOCK_GALEON		    "kz-galeon"
#define KZ_STOCK_NETSCAPE	    "kz-netscape"
#define KZ_STOCK_KONQUEROR 	    "kz-konqueror"

extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;

extern GdkPixbuf *kz_icon;

void kz_icons_init (void);

G_END_DECLS

#endif /* KZ_ICONS_H */
